import { Http } from "@angular/http";
import { Observable } from "rxjs";
import "rxjs/add/observable/of";
import { IServiceConfig } from "../service.config";
import { RequestQueryParams } from "./RequestQueryParams";
import { Endpoint } from "./interface";
/**
 * Define the service methods to handle the endpoint related things.
 *
 **
 * @abstract
 * class EndpointService
 */
export declare abstract class EndpointService {
    /**
     * Get all the endpoints.
     * Set the argument 'endpointName' to return only the endpoints match the name pattern.
     *
     * @abstract
     *  ** deprecated param {string} [endpointName]
     *  ** deprecated param {RequestQueryParams} [queryParams]
     * returns {(Observable<Endpoint[]> | Endpoint[])}
     *
     * @memberOf EndpointService
     */
    abstract getEndpoints(endpointName?: string, queryParams?: RequestQueryParams): Observable<Endpoint[]> | Promise<Endpoint[]> | Endpoint[];
    /**
     * Get the specified endpoint.
     *
     * @abstract
     *  ** deprecated param {(number | string)} endpointId
     * returns {(Observable<Endpoint> | Endpoint)}
     *
     * @memberOf EndpointService
     */
    abstract getEndpoint(endpointId: number | string): Observable<Endpoint> | Promise<Endpoint> | Endpoint;
    /**
     * Create new endpoint.
     *
     * @abstract
     *  ** deprecated param {Endpoint} endpoint
     * returns {(Observable<any> | any)}
     *
     * @memberOf EndpointService
     */
    abstract createEndpoint(endpoint: Endpoint): Observable<any> | Promise<any> | any;
    /**
     * Update the specified endpoint.
     *
     * @abstract
     *  ** deprecated param {(number | string)} endpointId
     *  ** deprecated param {Endpoint} endpoint
     * returns {(Observable<any> | any)}
     *
     * @memberOf EndpointService
     */
    abstract updateEndpoint(endpointId: number | string, endpoint: Endpoint): Observable<any> | Promise<any> | any;
    /**
     * Delete the specified endpoint.
     *
     * @abstract
     *  ** deprecated param {(number | string)} endpointId
     * returns {(Observable<any> | any)}
     *
     * @memberOf EndpointService
     */
    abstract deleteEndpoint(endpointId: number | string): Observable<any> | Promise<any> | any;
    /**
     * Ping the specified endpoint.
     *
     * @abstract
     *  ** deprecated param {Endpoint} endpoint
     * returns {(Observable<any> | any)}
     *
     * @memberOf EndpointService
     */
    abstract pingEndpoint(endpoint: Endpoint): Observable<any> | Promise<any> | any;
    /**
     * Check endpoint whether in used with specific replication rule.
     *
     * @abstract
     *  ** deprecated param {{number | string}} endpointId
     * returns {{Observable<any> | any}}
     */
    abstract getEndpointWithReplicationRules(endpointId: number | string): Observable<any> | Promise<any> | any;
}
/**
 * Implement default service for endpoint.
 *
 **
 * class EndpointDefaultService
 * extends {EndpointService}
 */
export declare class EndpointDefaultService extends EndpointService {
    private http;
    _endpointUrl: string;
    constructor(config: IServiceConfig, http: Http);
    getEndpoints(endpointName?: string, queryParams?: RequestQueryParams): Observable<Endpoint[]> | Promise<Endpoint[]> | Endpoint[];
    getEndpoint(endpointId: number | string): Observable<Endpoint> | Promise<Endpoint> | Endpoint;
    createEndpoint(endpoint: Endpoint): Observable<any> | Promise<any> | any;
    updateEndpoint(endpointId: number | string, endpoint: Endpoint): Observable<any> | Promise<any> | any;
    deleteEndpoint(endpointId: number | string): Observable<any> | Promise<any> | any;
    pingEndpoint(endpoint: Endpoint): Observable<any> | Promise<any> | any;
    getEndpointWithReplicationRules(endpointId: number | string): Observable<any> | Promise<any> | any;
}
