import { Http } from "@angular/http";
import "rxjs/add/observable/of";
import { Observable } from "rxjs/Observable";
import { RequestQueryParams } from "./RequestQueryParams";
import { HelmChartItem, HelmChartVersion, HelmChartDetail } from "./interface";
import { IServiceConfig } from "../service.config";
/**
 * Define service methods for handling the helmchart related things.
 * Loose couple with project module.
 *
 **
 * @abstract
 * class RepositoryService
 */
export declare abstract class HelmChartService {
    /**
     * Get all helm charts info
     *  ** deprecated param projectName Id of the project
     *  ** deprecated param queryParams options params for query data
     */
    abstract getHelmCharts(projectName: string, queryParams?: RequestQueryParams): Observable<HelmChartItem[]>;
    /**
     * Delete an helmchart
     *  ** deprecated param projectId Id of the project
     *  ** deprecated param chartId ID of helmChart in this specific project
     */
    abstract deleteHelmChart(projectId: number | string, chartId: number): Observable<any>;
    /**
     * Get all the versions of helmchart
     *  ** deprecated param projectName Id of the project
     *  ** deprecated param chartName ID of the helm chart
     *  ** deprecated param queryParams option params for query
     */
    abstract getChartVersions(projectName: string, chartName: string): Observable<HelmChartVersion[]>;
    /**
     * Delete a version of helmchart
     *  ** deprecated param projectName ID of the project
     *  ** deprecated param chartName ID of the chart you want to delete
     *  ** deprecated param version name of the version
     */
    abstract deleteChartVersion(projectName: string, chartName: string, version: string): Observable<any>;
    /**
     * Get the all details of an helmchart
     *  ** deprecated param projectName ID of the project
     *  ** deprecated param chartname ID of the chart
     *  ** deprecated param version name of the chart's version
     *  ** deprecated param queryParams options
     */
    abstract getChartDetail(projectName: string, chartname: string, version: string): Observable<HelmChartDetail>;
    /**
     * Download an specific verison
     *  ** deprecated param projectName ID of the project
     *  ** deprecated param filename ID of the helm chart
     *  ** deprecated param version Name of version
     *  ** deprecated param queryParams options
     */
    abstract downloadChart(projectName: string, filename: string): Observable<any>;
    /**
     * Upload chart and prov files to chartmuseam
     *  ** deprecated param projectName Name of the project
     *  ** deprecated param chart chart file
     *  ** deprecated param prov prov file
     */
    abstract uploadChart(projectName: string, chart: File, prov: File): Observable<any>;
}
/**
 * Implement default service for helm chart.
 */
export declare class HelmChartDefaultService extends HelmChartService {
    private http;
    private config;
    constructor(http: Http, config: IServiceConfig);
    private extractData;
    private extractHelmItems;
    private handleErrorObservable;
    getHelmCharts(projectName: string): Observable<HelmChartItem[]>;
    deleteHelmChart(projectId: number | string, chartId: number): any;
    getChartVersions(projectName: string, chartName: string): Observable<HelmChartVersion[]>;
    deleteChartVersion(projectName: string, chartName: string, version: string): any;
    getChartDetail(projectName: string, chartName: string, version: string): Observable<HelmChartDetail>;
    downloadChart(projectName: string, filename: string): Observable<any>;
    uploadChart(projectName: string, chart?: File, prov?: File): Observable<any>;
}
