import { Http } from "@angular/http";
import { Observable } from "rxjs";
import "rxjs/add/observable/of";
import { IServiceConfig } from "../service.config";
import { RequestQueryParams } from "./RequestQueryParams";
import { VulnerabilityItem, VulnerabilitySummary } from "./interface";
/**
 * Get the vulnerabilities scanning results for the specified tag.
 *
 **
 * @abstract
 * class ScanningResultService
 */
export declare abstract class ScanningResultService {
    /**
     * Get the summary of vulnerability scanning result.
     *
     * @abstract
     *  ** deprecated param {string} tagId
     * returns {(Observable<VulnerabilitySummary> | Promise<VulnerabilitySummary> | VulnerabilitySummary)}
     *
     * @memberOf ScanningResultService
     */
    abstract getVulnerabilityScanningSummary(repoName: string, tagId: string, queryParams?: RequestQueryParams): Observable<VulnerabilitySummary> | Promise<VulnerabilitySummary> | VulnerabilitySummary;
    /**
     * Get the detailed vulnerabilities scanning results.
     *
     * @abstract
     *  ** deprecated param {string} tagId
     * returns {(Observable<VulnerabilityItem[]> | Promise<VulnerabilityItem[]> | VulnerabilityItem[])}
     *
     * @memberOf ScanningResultService
     */
    abstract getVulnerabilityScanningResults(repoName: string, tagId: string, queryParams?: RequestQueryParams): Observable<VulnerabilityItem[]> | Promise<VulnerabilityItem[]> | VulnerabilityItem[];
    /**
     * Start a new vulnerability scanning
     *
     * @abstract
     *  ** deprecated param {string} repoName
     *  ** deprecated param {string} tagId
     * returns {(Observable<any> | Promise<any> | any)}
     *
     * @memberOf ScanningResultService
     */
    abstract startVulnerabilityScanning(repoName: string, tagId: string): Observable<any> | Promise<any> | any;
    /**
     * Trigger the scanning all action.
     *
     * @abstract
     * returns {(Observable<any> | Promise<any> | any)}
     *
     * @memberOf ScanningResultService
     */
    abstract startScanningAll(): Observable<any> | Promise<any> | any;
}
export declare class ScanningResultDefaultService extends ScanningResultService {
    private http;
    private config;
    _baseUrl: string;
    constructor(http: Http, config: IServiceConfig);
    getVulnerabilityScanningSummary(repoName: string, tagId: string, queryParams?: RequestQueryParams): Observable<VulnerabilitySummary> | Promise<VulnerabilitySummary> | VulnerabilitySummary;
    getVulnerabilityScanningResults(repoName: string, tagId: string, queryParams?: RequestQueryParams): Observable<VulnerabilityItem[]> | Promise<VulnerabilityItem[]> | VulnerabilityItem[];
    startVulnerabilityScanning(repoName: string, tagId: string): Observable<any> | Promise<any> | any;
    startScanningAll(): Observable<any> | Promise<any> | any;
}
