import { Http } from "@angular/http";
import { Observable } from "rxjs";
import "rxjs/add/observable/of";
import { IServiceConfig } from "../service.config";
import { RequestQueryParams } from "./RequestQueryParams";
import { Tag } from "./interface";
/**
 * For getting tag signatures.
 * This is temporary, will be removed in future.
 *
 **
 * class VerifiedSignature
 */
export declare class VerifiedSignature {
    tag: string;
    hashes: {
        sha256: string;
    };
}
/**
 * Define the service methods to handle the repository tag related things.
 *
 **
 * @abstract
 * class TagService
 */
export declare abstract class TagService {
    /**
     * Get all the tags under the specified repository.
     * NOTES: If the Notary is enabled, the signatures should be included in the returned data.
     *
     * @abstract
     *  ** deprecated param {string} repositoryName
     *  ** deprecated param {RequestQueryParams} [queryParams]
     * returns {(Observable<Tag[]> | Promise<Tag[]> | Tag[])}
     *
     * @memberOf TagService
     */
    abstract getTags(repositoryName: string, queryParams?: RequestQueryParams): Observable<Tag[]> | Promise<Tag[]> | Tag[];
    /**
     * Delete the specified tag.
     *
     * @abstract
     *  ** deprecated param {string} repositoryName
     *  ** deprecated param {string} tag
     * returns {(Observable<any> | any)}
     *
     * @memberOf TagService
     */
    abstract deleteTag(repositoryName: string, tag: string): Observable<any> | Promise<any> | any;
    /**
     * Get the specified tag.
     *
     * @abstract
     *  ** deprecated param {string} repositoryName
     *  ** deprecated param {string} tag
     * returns {(Observable<Tag> | Promise<Tag> | Tag)}
     *
     * @memberOf TagService
     */
    abstract getTag(repositoryName: string, tag: string, queryParams?: RequestQueryParams): Observable<Tag> | Promise<Tag> | Tag;
    abstract addLabelToImages(repoName: string, tagName: string, labelId: number): Observable<any> | Promise<any> | any;
    abstract deleteLabelToImages(repoName: string, tagName: string, labelId: number): Observable<any> | Promise<any> | any;
}
/**
 * Implement default service for tag.
 *
 **
 * class TagDefaultService
 * extends {TagService}
 */
export declare class TagDefaultService extends TagService {
    private http;
    private config;
    _baseUrl: string;
    _labelUrl: string;
    constructor(http: Http, config: IServiceConfig);
    _getTags(repositoryName: string, queryParams?: RequestQueryParams): Promise<Tag[]>;
    _getSignatures(repositoryName: string): Promise<VerifiedSignature[]>;
    getTags(repositoryName: string, queryParams?: RequestQueryParams): Observable<Tag[]> | Promise<Tag[]> | Tag[];
    deleteTag(repositoryName: string, tag: string): Observable<any> | Promise<Tag> | any;
    getTag(repositoryName: string, tag: string, queryParams?: RequestQueryParams): Observable<Tag> | Promise<Tag> | Tag;
    addLabelToImages(repoName: string, tagName: string, labelId: number): Observable<any> | Promise<any> | any;
    deleteLabelToImages(repoName: string, tagName: string, labelId: number): Observable<any> | Promise<any> | any;
}
